@@ -19,12 +19,14 @@ public:
     inline QString serviceName() const { return QString("Depositfiles"); }
     QRegExp urlPattern() const;
     bool urlSupported(const QUrl &url) const;
-    void checkUrl(const QUrl &webUrl);
-    void getDownloadUrl(const QUrl &webUrl);
+    void checkUrl(const QUrl &url);
+    void getDownloadRequest(const QUrl &url);
     inline bool loginSupported() const { return true; }
     void login(const QString &username, const QString &password);
     inline bool recaptchaRequired() const { return true; }
     inline QString recaptchaKey() const { return m_captchaKey; }
+    inline int maximumConnections() const { return m_connections; }
+    bool cancelCurrentOperation();
 
 public slots:
     void submitCaptchaResponse(const QString &challenge, const QString &response);
@@ -41,11 +43,15 @@ private slots:
     void downloadCaptcha();
     void onWaitFinished();
 
+signals:
+    void currentOperationCancelled();
+
 private:
     QString m_fileId;
     QString m_captchaKey;
     QTimer *m_waitTimer;
     int m_waitTime;
+    int m_connections;
 };
 
 #endif // DEPOSITFILES_H
